<?php
/**
 * $Horde: gollem/xppublish.php,v 1.15 2005/01/03 14:34:54 jan Exp $
 *
 * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('AUTH_HANDLER', true);
@define('GOLLEM_BASE', dirname(__FILE__));
$authentication = 'none';
require_once GOLLEM_BASE . '/lib/base.php';
require GOLLEM_BASE . '/config/credentials.php';

$cmd = Util::getFormData('cmd');
if (empty($cmd)) {
    $browser->downloadHeaders('install_registry.reg', 'application/octet-stream');

    $lines = array('Windows Registry Editor Version 5.00',
                   '',
                   '[HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\PublishingWizard\PublishingWizard\Providers\\' . $registry->getApp() . '-' . $conf['server']['name'] . ']',
                   '"displayname"="' . $registry->get('name') . '"',
                   '"description"="' . sprintf(_("Upload your files to %s on %s."), $registry->get('name'), $conf['server']['name']) . '"',
                   '"href"="' . Horde::applicationUrl(Util::addParameter('xppublish.php', 'cmd', 'publish'), true, -1) . '"',
                   '"icon"="' . Horde::url($registry->getImageDir() . '/favicon.ico', true, -1) . '"');
    echo implode("\r\n", $lines) . "\r\n";
    exit;
}

$PUBLISH_BUTTONS = 'false,true,false';
$PUBLISH_ONBACK = '';
$PUBLISH_ONNEXT = '';
$PUBLISH_CMD = '';

$title = sprintf(_("Upload to %s"), $registry->get('name'));
require GOLLEM_TEMPLATES . '/common-header.inc';

// Check for a login.
if ($cmd == 'login') {
    $username = Util::getFormData('username');
    $password = Util::getFormData('password');
    if ($username && $password) {
        $auth = &Auth::singleton($conf['auth']['driver']);
        if ($auth->authenticate($username, array('password' => $password))) {
            $cmd = 'list';
            $PUBLISH_BUTTONS = 'true,true,false';
            $PUBLISH_ONBACK = 'history.go(-1);';
        } else {
            echo '<span class="form-error">' . _("Username and Password are incorrect.") . '</span>';
            $PUBLISH_BUTTONS = 'false,true,false';
        }
    } else {
        echo '<span class="form-error">'. _("Please enter your Username and Password.") . '</span>';
        $PUBLISH_BUTTONS = 'false,true,false';
    }
}

// If we don't have a valid login, print the login form.
if (!Auth::getAuth()) {
    $PUBLISH_ONNEXT = 'login.submit();';
    $PUBLISH_CMD = 'login.username.focus();';
    require GOLLEM_TEMPLATES . '/xppublish/login.inc';
    require GOLLEM_TEMPLATES . '/xppublish/javascript.inc';
    require $registry->get('templates', 'horde') . '/common-footer.inc';
    exit;
}

// If we don't have a valid Gollem session, try hordeauth/autologin,
// and if that fails, make the user select a backend.
if (!(Gollem::checkAuthentication(false) && Gollem::changeDir())) {
    $backend_key = Gollem::getPreferredBackend();
    $user = Auth::getBareAuth();
    $pass = Auth::getCredential('password');

    require GOLLEM_BASE . '/config/backends.php';

    if ($backends[$backend_key]['driver'] == 'ftp') {
        $port_value = $backends[$backend_key]['params']['port'];
        $server_value = $backends[$backend_key]['params']['hostspec'];
    } else {
        $port_value = '';
        $server_value = _("Locked");
    }

    /* Build the <select> widget for the servers list. */
    if ($conf['backend']['backend_list'] == 'shown') {
        $backends_list = '';
        foreach ($backends as $key => $curBackend) {
            $sel = ($key == $backend_key) ? ' selected="selected"' : '';
            $backends_list .= "<option value=\"$key\"$sel>";
            $backends_list .= $curBackend['name'] . '</option>';
            $login_vfs[$backend_key] = &VFS::singleton($backends[$backend_key]['driver'], array_merge($backends[$backend_key]['params'], array('user' => Auth::getAuth())));
        }
    }
    $GLOBALS['vfs'] = $login_vfs[$backend_key];

    // See if we can log in without any more credentials.
    require_once GOLLEM_BASE . '/lib/Session.php';
    if (Gollem::canAutoLogin($backend_key) &&
        Gollem_Session::createSession($backend_key, $user, $pass) &&
        Gollem::changeDir()) {
        $cmd = 'browse';
    } else {
        $PUBLISH_ONNEXT = 'login.submit();';
        $PUBLISH_CMD = 'login.username.focus();';
        require GOLLEM_TEMPLATES . '/xppublish/backend.inc';
        require GOLLEM_TEMPLATES . '/xppublish/javascript.inc';
        require $registry->get('templates', 'horde') . '/common-footer.inc';
        exit;
    }
}

// We're selecting a folder.
if ($cmd == 'browse') {
    $PUBLISH_ONNEXT = 'folder.submit();'; 
    $PUBLISH_ONBACK = 'window.location.href="' . Util::addParameter(Horde::applicationUrl('xppublish.php', true), 'cmd', 'publish') . '";';
    $PUBLISH_BUTTONS = 'true,true,true';
    require GOLLEM_TEMPLATES . '/xppublish/browse.inc';
}

// We've chosen the destination folder; go ahead and upload.
if ($cmd == 'select') {
    echo '<form id="folder">';
    Util::pformInput();
    echo '<input type="hidden" name="dir" value="' . Gollem::getDir() . '">';
    echo '</form>';

    $PUBLISH_CMD = 'publish();';
}

// We're uploading a file.
if ($cmd == 'upload') {
    $error = false;
    $res = Browser::wasFileUploaded('file_upload');
    if (is_a($res, 'PEAR_Error')) {
        $error = $res->getMessage();
    } else {
        $res = $vfs->write(Gollem::getDir(), $_FILES['file_upload']['name'], $_FILES['file_upload']['tmp_name']);
        if (is_a($res, 'PEAR_Error')) {
            $error = $res->getMessage();
        }
    }

    if ($error) {
        printf(_("ERROR: %s"), $error);
    } else {
        echo 'SUCCESS';
    }
}

require GOLLEM_TEMPLATES . '/xppublish/javascript.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
